@@ -35,7 +35,7 @@
 #' @param posi Legend position
 #' @param point Point type for regression ("mean_se","mean_sd","mean" or "all")
 #' @param angle.label Label angle
-#' @note The ordering of the graph is according to the sequence in which the factor levels are arranged in the data sheet. The bars of the column and segment graphs are standard deviation.
+#' @note The order of the chart follows the alphabetical pattern. Please use `scale_x_discrete` from package ggplot2, `limits` argument to reorder x-axis. The bars of the column and segment graphs are standard deviation.
 #' @note In the final output when transformation (transf argument) is different from 1, the columns resp and respo in the mean test are returned, indicating transformed and non-transformed mean, respectively.
 #' @import ggplot2
 #' @importFrom crayon green
@@ -113,6 +113,15 @@ PSUBDBC=function(f1,
   requireNamespace("crayon")
   requireNamespace("ggplot2")
   requireNamespace("nortest")
+  organiz=data.frame(f1,f2,block,response)
+  organiz=organiz[order(organiz$block),]
+  organiz=organiz[order(organiz$f2),]
+  organiz=organiz[order(organiz$f1),]
+  f1=organiz$f1
+  f2=organiz$f2
+  block=organiz$block
+  response=organiz$response
+
   fator1=f1
   fator2=f2
   fator1a=fator1
