@@ -16,6 +16,7 @@
 #' @param label.x text in x
 #' @param label.y text in y
 #' @param labelsize Label size
+#' @param axissize Axis size
 #' @param add.streets.x Adds streets by separating treatments in row or column. The user must supply a numeric vector grouping the rows or columns that must be together. See the example.
 #' @param add.streets.y Adds streets by separating treatments in row or column. The user must supply a numeric vector grouping the rows or columns that must be together. See the example.
 #' @param export.csv Save table template based on sketch in csv
@@ -100,6 +101,7 @@ sketch=function(trat,
                 add.streets.x=NA,
                 label.x="",
                 label.y="",
+                axissize=12,
                 labelsize=4,
                 export.csv=FALSE,
                 comment.caption=NULL){
@@ -344,10 +346,10 @@ sketch=function(trat,
   if(pos=="line"){graph=ggplot(data,aes(x=x,y=y))+
     geom_tile(aes(fill=separate),color="black")+
     labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
   if(pos=="column"){graph=ggplot(data,aes(y=x,x=y,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
@@ -355,7 +357,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -380,7 +382,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -423,10 +425,10 @@ sketch=function(trat,
 
   if(pos=="line"){graph=ggplot(data,aes(x=x,y=block,fill=separate))+
     geom_tile(color="black")+labs(y="Block",x=label.x,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
   if(pos=="column"){graph=ggplot(data,aes(y=x,x=block,fill=separate))+
     geom_tile(color="black")+labs(y=label.y,x="Block",fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     data$block=factor(data$block,levels = rev(unique(data$block)))
@@ -434,7 +436,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(x=x,y=block,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y="Block",fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -456,10 +458,11 @@ sketch=function(trat,
               strip.text = element_blank(),
               line = element_blank())}
     if(pos=="column"){
+      data$block=factor(data$block,levels = unique(data$block))
       graph=ggplot(data,aes(y=x,x=block,fill=separate))+
         geom_tile(color="black")+
         labs(x="Block",y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -501,7 +504,7 @@ sketch=function(trat,
 
   graph=ggplot(data,aes(x=row,y=col,fill=separate))+
     geom_tile(color="black")+labs(x="Row",y="Column",fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     data$row=factor(data$row,levels = rev(unique(data$row)))
@@ -553,17 +556,17 @@ sketch=function(trat,
 
   if(pos=="column"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
   if(pos=="line"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
       data$y=factor(data$y,levels = rev(unique(data$y)))
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -589,7 +592,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -635,16 +638,16 @@ sketch=function(trat,
 
   if(pos=="column"){graph=ggplot(data,aes(y=x,x=block,fill=separate))+
     geom_tile(color="black")+labs(x="Block",y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
   if(pos=="line"){graph=ggplot(data,aes(y=block,x=x,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
       data$y=factor(data$block,levels = rev(unique(data$block)))
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -670,7 +673,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x="Block",y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -757,7 +760,7 @@ sketch=function(trat,
         ylab("")+xlab("")+
         geom_text(aes(label=paste(t1,t2)))+
         theme_classic()+theme(axis.line = element_blank(),
-                              axis.text=element_text(size=12),
+                              axis.text=element_text(size=axissize),legend.text=element_text(size=axissize),
                               strip.text = element_text(size=12))}
     requireNamespace("cowplot")
     graph=do.call("plot_grid", c(graphs, ncol=length(levels(book$block))))
@@ -786,17 +789,17 @@ sketch=function(trat,
 
   if(pos=="column"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
   if(pos=="line"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
     geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-    theme_classic()+theme(axis.line = element_blank())}
+    theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
 
   if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
     if(pos=="line"){
       data$y=factor(data$y,levels = rev(unique(data$y)))
       graph=ggplot(data,aes(x=x,y=y,fill=separate))+
         geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -822,7 +825,7 @@ sketch=function(trat,
       graph=ggplot(data,aes(y=x,x=y,fill=separate))+
         geom_tile(color="black")+
         labs(x=label.x,y=label.y,fill="Treatments")+
-        theme_classic()
+        theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
       if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
         ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -875,17 +878,17 @@ sketch=function(trat,
 
     if(pos=="column"){graph=ggplot(data,aes(y=x,x=block,fill=separate))+
       geom_tile(color="black")+labs(x="Block",y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
     if(pos=="line"){graph=ggplot(data,aes(y=block,x=x,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
 
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$block,levels = rev(unique(data$block)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -911,7 +914,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x="Block",y=label.y,fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -964,16 +967,16 @@ sketch=function(trat,
 
     if(pos=="line"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
     if(pos=="column"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$y,levels = rev(unique(data$y)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y=label.y,fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -999,7 +1002,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x=label.x,y=label.y,fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -1055,17 +1058,17 @@ sketch=function(trat,
 
     if(pos=="line"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
       geom_tile(color="black")+labs(x="block",y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
     if(pos=="column"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y="block",fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
 
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$y,levels = rev(unique(data$y)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
@@ -1091,7 +1094,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x="Block",y=label.y,fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -1154,17 +1157,17 @@ sketch=function(trat,
 
     if(pos=="line"){graph=ggplot(data,aes(x=y,y=x,fill=separate))+
       geom_tile(color="black")+labs(x="block",y=label.y,fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
     if(pos=="column"){graph=ggplot(data,aes(x=x,y=y,fill=separate))+
       geom_tile(color="black")+labs(x=label.x,y="block",fill="Treatments")+
-      theme_classic()+theme(axis.line = element_blank())}
+      theme_classic()+theme(axis.line = element_blank())+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))}
 
     if(is.na(add.streets.x[1])==FALSE | is.na(add.streets.y[1])==FALSE){
       if(pos=="line"){
         data$y=factor(data$y,levels = rev(unique(data$y)))
         graph=ggplot(data,aes(x=x,y=y,fill=separate))+
           geom_tile(color="black")+labs(x=label.x,y="Block",fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,(length(data$x)/length(add.streets.x)))
@@ -1190,7 +1193,7 @@ sketch=function(trat,
         graph=ggplot(data,aes(y=x,x=y,fill=separate))+
           geom_tile(color="black")+
           labs(x="Block",y=label.y,fill="Treatments")+
-          theme_classic()
+          theme_classic()+theme(axis.text=element_text(size=axissize),legend.text=element_text(size=axissize))
 
         if(is.na(add.streets.x[1])==FALSE & is.na(add.streets.y[1])==TRUE){
           ruas1=rep(add.streets.x,e=(length(data$x)/length(add.streets.x)))
